#
# spec file for package taisei
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{suse_version} >= 1550
%define shader_translation 1
%else
%define shader_translation 0
%endif

Name:           taisei
Version:        1.3.2
Release:        2.13
Summary:        Clone of the Touhou Project series of shoot ’em up games
License:        MIT
Group:          Amusements/Games/Action/Arcade
URL:            https://taisei-project.org
Source0:        https://github.com/taisei-project/taisei/releases/download/v%{version}/taisei-v%{version}.tar.xz
Source1:        https://github.com/taisei-project/taisei/releases/download/v%{version}/taisei-v%{version}.tar.xz.sig
Source2:        gpg.keyring
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson >= 0.49.0
BuildRequires:  pkgconfig
BuildRequires:  python3-Pygments
BuildRequires:  python3-docutils
BuildRequires:  pkgconfig(SDL2_mixer) >= 2.0.4
BuildRequires:  pkgconfig(cglm)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gamemode)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libwebpdecoder) > 0.4
BuildRequires:  pkgconfig(libzip)
BuildRequires:  pkgconfig(opusfile)
BuildRequires:  pkgconfig(sdl2) >= 2.0.5
BuildRequires:  pkgconfig(zlib)
%if %{shader_translation}
BuildRequires:  pkgconfig(shaderc)
BuildRequires:  pkgconfig(spirv-cross-c-shared)
%endif
Requires:       %{name}-data
Suggests:       gamemoded
ExcludeArch:    %{ix86}

%description
Taisei is an open clone of the Touhou Project series. Touhou is a one-man project
of shoot ’em up games set in an isolated world full of Japanese folklore.

%package data
Summary:        Data files for Taisei
Group:          Amusements/Games/Action/Arcade
Requires:       %{name} >= %{version}
BuildArch:      noarch

%description data
Data files for Taisei, an open clone of the Touhou Project series. Touhou is a
one-man project of shoot ’em up games set in an isolated world full of
Japanese folklore.

%prep
%setup -q -n %{name}-v%{version}

%build
_v=%{version}
%meson \
    -Dstrip=false \
    -Db_pch=false \
    -Dversion_fallback=${_v//.g/-g} \
%if %{shader_translation}
    -Dshader_transpiler=true \
    -Dr_gles30=true \
%endif
%meson_build

%install
%meson_install

%if 0%{?suse_version} && !0%{?fedora_version}
mkdir -p %{buildroot}%{_docdir}
mv %{buildroot}%{_datadir}/doc/%{name} %{buildroot}%{_docdir}/%{name}
%endif
%fdupes %{buildroot}

%files
%{_docdir}/%{name}
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/applications/%{name}-replay-viewer.desktop
%{_datadir}/icons/hicolor/128x128/apps/%{name}.png
%{_datadir}/icons/hicolor/256x256/mimetypes/taisei-replay.png
%{_datadir}/mime/packages/taisei.xml

%files data
%{_datadir}/%{name}

%changelog
* Wed Nov 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Do not build for %%ix86: cglm is not available on this platform.
* Sat May  8 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- New public key: 5F2EE4A69653CA07
  * See https://github.com/taisei-project/taisei/releases/tag/v1.3.2
* Mon May  3 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.3.2
  * Fixed some rendering errors, including the Stage 1 water effect
    on Intel iGPUs and incorrect laser blurring.
  * Improved support for high-DPI displays.
  * Slightly optimized various parts of the engine, including 3D
    and text rendering.
  * Added GameMode integration on Linux. If you use GameMode daemon,
    GameMode will now be automatically activated when you start Taisei.
  * Updated the SDL game controller database, enabling
    out-of-the-box support for even more controllers.
* Wed Oct  2 2019 Martin Herkt <9+suse@cirno.systems>
- Switch back to GitHub download URLs
* Sun Sep 29 2019 Martin Herkt <9+suse@cirno.systems>
- Update to version 1.3.1
  * Improved laser rendering and other visual Improvements
  * Names and declaration animations for player spell cards
  * Various shader performance optimizations
  * Audio assets now in Opus format
  * Bugfixes backported from 1.4 development
  * New character art by @afensorm
* Sat Apr 27 2019 Martin Herkt <9+suse@cirno.systems>
- Update to version 1.3
  * Improved performance
  * Improved graphics
  * Added Reimu character
  * New scoring mechanic
  * New shot mode B for Marisa character
  * Added Music Room
  * Changed Bombs
  * Fixed collisions
  * Improved bullet patterns
* Fri May 25 2018 9+suse@cirno.systems
- Tōhō -> Touhou for better discoverability
* Fri Jan 26 2018 9+suse@cirno.systems
- Update to version 1.2, adding tons of new game content
- Remove taisei-make-rpmlint-happy.patch
- Remove add taisei-use-std-gnu11.patch
* Fri Dec 22 2017 9@cirno.systems
- Fix ppc64le
  * add taisei-use-std-gnu11.patch
* Fri Dec  8 2017 9@cirno.systems
- Split data files into separate RPM package
- spec-cleaner
* Mon Nov 20 2017 9@cirno.systems
- Add taisei-make-rpmlint-happy.patch
* Mon Nov 20 2017 9@cirno.systems
- Update to version 1.1.2
  * Flush stdio on logging shutdown
  * Make sfx/bgm resources always optional
  * Improvements to vfs code
  * Avoid strtok_r clashes with libc implementations
  * Fix fullscreen/window management issues
  * More robust SDL video driver selection
  * Fix capitalization of Occam’s Razor
  * Fix SDL2_mixer initialization
* Wed Nov  8 2017 9@cirno.systems
- Update to version 1.1.1
  * Vertical synchronization (vsync) is now disabled by default,
    as it causes percieved input latency for some players.
    If you'd like to use it and/or you have screen tearing
    problems, you should set it to "on" or "adaptive" in the video
    settings.
  * The event/input processing system has been completely
    rewritten, and unicode text input now works correctly.
  * Reimplemented the framerate limiter. It's significantly more
    accurate now and attempts to compensate for sudden frametime
    spikes. This makes the game much more likely to run at exactly
    the intended speed (60 frames per second).
  * The character's Power is now also displayed as a numeric value,
    in addition to the stars bar.
  * Fixed an unpleasant artifact in the boss background shader.
  * Fixed the "letterboxing" artifacts on some systems on non-4:3
    resolutions.
  * Updated the SDL game controller database. More gamepads are
    supported out-of-the-box now.
  * Fixed the character getting stuck moving in some direction when
    using some gamepads in the "restricted" axes mode.
  * Fixed memory corruption that could occur when a gamepad has
    fewer axes than expected of an Xbox-like controller.
* Thu Jul 13 2017 9@cirno.systems
- Initial package
